==> lava_2020.12.orig.tar.gz: lava-2020.12/doc/content/introduction/contact.md <==
# Mailing-lists

The best way to get in touch with the community and the LAVA developers is via [mailing-lists](https://lists.lavasoftware.org).

## [lava-announce](mailto:lava-announce@lists.lavasoftware.org)

Subscribing to the **lava-announce** list is recommended for everyone using LAVA, whether writing tests or viewing reports or administering a LAVA instance.

The release notes for each production release are sent to the **lava-announce** mailing list.

Replies to this list are sent to the **lava-users** list.


## [lava-devel](mailto:lava-devel@lists.lavasoftware.org)

Subscribing to the **lava-devel** list is recommended for developers of LAVA.

**lava-devel** is aimed at supporting code contributors, device integration engineers and instance admins who are working with the LAVA codebase.
Discussions about planning and new LAVA features also take place here.

## [lava-users](mailto:lava-users@lists.lavasoftware.org)

The **lava-users** mailing list concentrates on support for setting up and using LAVA.

Subscribers include test writers, and individual admins.
Users are encouraged to contribute to answer queries from other users.
Replies to the **lava-announce** list are directed here.


# IRC

IRC is a common support method for developers. Our team is spread geographically around the world, with members in Europe, America and Asia.

The LAVA Software Community Project has an IRC channel, `#lavasoftware` on [irc.freenode.net](https://webchat.freenode.net/).

We can also be found on a IRC channel used for topics relating to the Linaro Lab in Cambridge, UK: `#linaro-lava` on [irc.freenode.net](https://webchat.freenode.net/).

==> lava_2024.09.orig.tar.gz: lava-2024.09/doc/content/introduction/contact.md <==
# Mailing-lists

The best way to get in touch with the community and the LAVA developers is via [mailing-lists](https://lists.lavasoftware.org).

## [lava-announce](mailto:lava-announce@lists.lavasoftware.org)

Subscribing to the **lava-announce** list is recommended for everyone using LAVA, whether writing tests or viewing reports or administering a LAVA instance.

The release notes for each production release are sent to the **lava-announce** mailing list.

Replies to this list are sent to the **lava-users** list.


## [lava-devel](mailto:lava-devel@lists.lavasoftware.org)

Subscribing to the **lava-devel** list is recommended for developers of LAVA.

**lava-devel** is aimed at supporting code contributors, device integration engineers and instance admins who are working with the LAVA codebase.
Discussions about planning and new LAVA features also take place here.

## [lava-users](mailto:lava-users@lists.lavasoftware.org)

The **lava-users** mailing list concentrates on support for setting up and using LAVA.

Subscribers include test writers, and individual admins.
Users are encouraged to contribute to answer queries from other users.
Replies to the **lava-announce** list are directed here.


# IRC

IRC is a common support method for developers. Our team is spread geographically around the world, with members in Europe, America and Asia.

The LAVA Software Community Project has an IRC channel, `#lavasoftware` on [irc.libera.chat](https://web.libera.chat/).

We can also be found on a IRC channel used for topics relating to the Linaro Lab in Cambridge, UK: `#linaro-lava` on [irc.libera.chat](https://web.libera.chat/).
